=====
Imply
=====

.. image:: https://img.shields.io/pypi/v/imply.svg
    :target: https://pypi.org/project/imply

.. image:: https://img.shields.io/pypi/pyversions/imply.svg
    :alt: Python versions
    :target: https://pypi.org/project/imply/

.. image:: https://api.travis-ci.org/seddonym/imply.svg?branch=master
    :target: https://travis-ci.org/seddonym/imply


Imply is a command line tool for exploring the imports in a Python package.

* Free software: BSD license

**Warning:** This software is currently being developed; it is not ready to use.
